import { IDocument, TAsyncDeleteDocument, TAsyncGetDocument, TAsyncPostDocument, TAsyncPutDocument, Uid, IDeleteResponse, ISaveResponse } from '@react_db_client/constants.client-types';
import { ICallback, AsyncRequestError } from '@react_db_client/async-hooks.use-async-request';
export interface IUseAsyncObjectManagerArgs<DocType extends IDocument> {
    activeUid?: null | Uid;
    collection: string;
    isNew?: boolean;
    inputAdditionalData?: null | Partial<DocType>;
    schema?: string | 'all';
    populate?: 'all' | string[];
    loadOnInit?: boolean;
    autoSave?: boolean;
    reloadOnSave?: boolean;
    onSavedCallback?: (uid: Uid, response: any, combinedData: DocType) => void;
    saveErrorCallback?: (e: AsyncRequestError) => void;
    onDeleteCallback?: ICallback<IDeleteResponse, [string, Uid]>;
    asyncGetDocument: TAsyncGetDocument<DocType>;
    asyncPutDocument: TAsyncPutDocument<DocType>;
    asyncPostDocument: TAsyncPostDocument<DocType>;
    asyncDeleteDocument: TAsyncDeleteDocument;
}
export interface IUseAsyncObjectManagerReturn<DocType extends IDocument> {
    loadedData?: Partial<DocType>;
    saveData: () => void;
    updateData: (newData: Partial<DocType>, save?: boolean) => void;
    updateField: (field: Uid, value: any, save?: boolean, nested?: string) => void;
    resetData: () => void;
    reload: () => void;
    deleteObject: () => void;
    saveResponse?: ISaveResponse;
    deleteResponse?: null | IDeleteResponse;
    loadingData: boolean;
    savingData: boolean;
    deletingData: boolean;
    data: Partial<DocType>;
    savedData?: Partial<DocType>;
    uid: Uid;
    callCount: number;
    hasLoaded: boolean;
    loadError?: AsyncRequestError;
    saveError?: AsyncRequestError;
    unsavedChanges: boolean;
    isNew: boolean;
}
export declare const useAsyncObjectManager: <DocType extends IDocument>({ activeUid, collection, isNew: isNewIn, inputAdditionalData, schema, populate, loadOnInit, autoSave, reloadOnSave, onSavedCallback: onSavedCallbackIn, saveErrorCallback, onDeleteCallback, asyncGetDocument, asyncPutDocument, asyncPostDocument, asyncDeleteDocument, }: IUseAsyncObjectManagerArgs<DocType>) => IUseAsyncObjectManagerReturn<DocType>;
